@@ -15,3 +15,7 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 from pm4py.algo.conformance.alignments.edit_distance import variants, algorithm
+
+import warnings
+
+warnings.warn("The edit_distance package will be removed in a future release.")
