@@ -28,8 +28,7 @@ class Parameters(Enum):
     TIMESTAMP_KEY = constants.PARAMETER_CONSTANT_TIMESTAMP_KEY
     AGGREGATION_MEASURE = "aggregationMeasure"
     BUSINESS_HOURS = "business_hours"
-    WORKTIMING  = "worktiming"
-    WEEKENDS = "weekends"
+    BUSINESS_HOUR_SLOTS = "business_hour_slots"
     WORKCALENDAR = "workcalendar"
 
 
@@ -51,11 +50,15 @@ def apply(dataframe: pd.DataFrame, parameters: Optional[Dict[Union[str, Paramete
         - Parameters.TIMESTAMP_KEY => timestamp key
         - Parameters.BUSINESS_HOURS => calculates the difference of time based on the business hours, not the total time.
                                         Default: False
-        - Parameters.WORKTIMING => work schedule of the company (provided as a list where the first number is the start
-            of the work time, and the second number is the end of the work time), if business hours are enabled
-                                        Default: [7, 17] (work shift from 07:00 to 17:00)
-        - Parameters.WEEKENDS => indexes of the days of the week that are weekend
-                                        Default: [6, 7] (weekends are Saturday and Sunday)
+        - Parameters.BUSINESS_HOURS_SLOTS =>
+        work schedule of the company, provided as a list of tuples where each tuple represents one time slot of business
+        hours. One slot i.e. one tuple consists of one start and one end time given in seconds since week start, e.g.
+        [
+            (7 * 60 * 60, 17 * 60 * 60),
+            ((24 + 7) * 60 * 60, (24 + 12) * 60 * 60),
+            ((24 + 13) * 60 * 60, (24 + 17) * 60 * 60),
+        ]
+        meaning that business hours are Mondays 07:00 - 17:00 and Tuesdays 07:00 - 12:00 and 13:00 - 17:00
         - Parameters.AGGREGATION_MEASURE => performance aggregation measure (sum, min, max, mean, median)
 
     Returns
@@ -67,8 +70,8 @@ def apply(dataframe: pd.DataFrame, parameters: Optional[Dict[Union[str, Paramete
         parameters = {}
 
     business_hours = exec_utils.get_param_value(Parameters.BUSINESS_HOURS, parameters, False)
-    worktiming = exec_utils.get_param_value(Parameters.WORKTIMING, parameters, [7, 17])
-    weekends = exec_utils.get_param_value(Parameters.WEEKENDS, parameters, [6, 7])
+    business_hours_slots = exec_utils.get_param_value(Parameters.BUSINESS_HOUR_SLOTS, parameters, constants.DEFAULT_BUSINESS_HOUR_SLOTS)
+
     workcalendar = exec_utils.get_param_value(Parameters.WORKCALENDAR, parameters, constants.DEFAULT_BUSINESS_HOURS_WORKCALENDAR)
 
     activity_key = exec_utils.get_param_value(Parameters.ACTIVITY_KEY, parameters, xes_constants.DEFAULT_NAME_KEY)
@@ -81,8 +84,7 @@ def apply(dataframe: pd.DataFrame, parameters: Optional[Dict[Union[str, Paramete
 
     if business_hours:
         dataframe[DIFF_KEY] = dataframe.apply(
-            lambda x: soj_time_business_hours_diff(x[start_timestamp_key], x[timestamp_key], worktiming,
-                                                   weekends, workcalendar), axis=1)
+            lambda x: soj_time_business_hours_diff(x[start_timestamp_key], x[timestamp_key], business_hours_slots, workcalendar), axis=1)
     else:
         dataframe[DIFF_KEY] = (
             dataframe[timestamp_key] - dataframe[start_timestamp_key]
